@@ -20,7 +20,7 @@ export HADOOP_CONF_DIR=/opt/soft/hadoop/etc/hadoop
 export SPARK_HOME1=/opt/soft/spark1
 export SPARK_HOME2=/opt/soft/spark2
 export PYTHON_HOME=/opt/soft/python
-export JAVA_HOME=/opt/soft/java
+export JAVA_HOME=${JAVA_HOME:-/opt/soft/java}
 export HIVE_HOME=/opt/soft/hive
 export FLINK_HOME=/opt/soft/flink
 export DATAX_HOME=/opt/soft/datax
